**To upload an SSH public key and associate it with a user**

The following ``upload-ssh-public-key`` command uploads the public key found in the file 'sshkey.pub' and attaches it to the user 'sofia'. ::

    aws iam upload-ssh-public-key --user-name sofia --ssh-public-key-body file://sshkey.pub

Output::

  {
      "SSHPublicKey": {
          "UserName": "sofia",
          "SSHPublicKeyId": "APKA1234567890EXAMPLE",
          "Fingerprint": "12:34:56:78:90:ab:cd:ef:12:34:56:78:90:ab:cd:ef",
          "SSHPublicKeyBody": "ssh-rsa <<long string generated by ssh-keygen command>>",
          "Status": "Active",
          "UploadDate": "2019-04-18T17:04:49+00:00"
      }
  }

For more information about how to generate keys in a format suitable for this command, see `SSH and Linux, macOS, or Unix: Set Up the Public and Private Keys for Git and CodeCommit`_ or `SSH and Windows: Set Up the Public and Private Keys for Git and CodeCommit`_in the *AWS CodeCommit User Guide*
.. _`SSH and Linux, macOS, or Unix: Set Up the Public and Private Keys for Git and CodeCommit`: https://docs.aws.amazon.com/codecommit/latest/userguide/setting-up-ssh-unixes.html#setting-up-ssh-unixes-keys
.. _`SSH and Windows: Set Up the Public and Private Keys for Git and CodeCommit`: https://docs.aws.amazon.com/codecommit/latest/userguide/setting-up-ssh-windows.html#setting-up-ssh-windows-keys-windows
